//
//  QuenchClient.m
//  Compare Prices
//
//  Created by Jesper Forsberg on 2011-08-12.
//  Copyright 2011 Jesper Forsberg. All rights reserved.
//

#import "QuenchClient.h"
#import "JSONKit.h"
#import "ASIHTTPRequest.h"
#import "NSString+HTML.h"

@interface QuenchClient ()

@property (nonatomic, retain) NSURL* baseUrl;	
- (NSString*) paramsToString:(NSDictionary*)dict;

@end

@implementation QuenchClient

@synthesize baseUrl, lastURL, applicationId, applicationKey;

- (void)dealloc
{
    [applicationId release];
    [applicationKey release];
    [lastURL release];
    [super dealloc];
}

- (id)init
{
    self = [super init];
    if (self) {
        // Initialization code here.
        self.baseUrl = [NSURL URLWithString:@"http://api-us.quenchnetworks.net"];
    }
    
    return self;
}

- (NSString *)paramsToString:(NSDictionary *)dict
{
    NSMutableString* s = [NSMutableString stringWithString:@""];
    
    NSString *delim = @"";
    NSString *key;
    for (key in dict) {
        NSString *val = [dict objectForKey:key];
        
        if (val == nil) {
            continue;
        }
        
        //val = [val stringByReplacingOccurrencesOfString:@" " withString:@"+"];
        
        val = [val URLEncodedString_ch];
        
        [s appendString:delim];
        [s appendString:key];
        [s appendString:@"="];
        [s appendString:val];
        delim = @"&";
    }
    
    return [NSString stringWithString:s];
}

- (NSData *)queryResource:(NSString *)resource withParams:(NSDictionary *)params
{
    return [self queryResource:resource withParams:params byMethod:@"GET" withData:nil];
}

- (NSData *)queryResource:(NSString *)resource withParams:(NSDictionary *)params byMethod:(NSString *)method withData:(NSDictionary *)data
{
    NSMutableDictionary *mutableParams = [NSMutableDictionary dictionaryWithDictionary:params];
    
    if (mutableParams == nil)
    {
        NSLog(@"mutableParams == nil :(");
    }
    
    [mutableParams setObject:[applicationId stringValue] forKey:@"applicationid"];
    [mutableParams setObject:applicationKey forKey:@"applicationkey"];
    
    NSMutableString *urlString = [NSMutableString stringWithString:[baseUrl absoluteString]];
    [urlString appendString:resource];
    [urlString appendString:@"?"];
    [urlString appendString:[self paramsToString:[NSDictionary dictionaryWithDictionary:mutableParams]]];
    
    lastURL = [NSString stringWithString:urlString];
    
    NSURL *url = [NSURL URLWithString:[NSString stringWithString:urlString]];
    
    NSLog(@"Querying %@", url);
    
    [ASIHTTPRequest setDefaultUserAgentString:@"objc client 1.0"];
    
    ASIHTTPRequest *request = [ASIHTTPRequest requestWithURL:url];
    [request setRequestMethod:method];
    [request setAllowCompressedResponse:YES];
    
    if (data != nil) {
        NSMutableData *postData = [NSMutableData dataWithData:[[self paramsToString:data] dataUsingEncoding:NSUTF8StringEncoding]];
        [request setPostBody:postData];
    }
    
    [request startSynchronous];
    NSError *error = [request error];
    
    if (!error) {
        int resultCode = [request responseStatusCode];
        
        if (resultCode == 404) {
            NSLog(@"Resource not found. 404");
        } else if (resultCode == 403) {
            NSLog(@"Access denied. Invalid authorization key.");
        }
        
        return [request responseData];
    } else {
        NSLog(@"%@", [error localizedDescription]);
        return nil;
    }
    
    return nil;
}

@end
