//
//  CategoryRequest.m
//  Compare Prices
//
//  Created by Jesper Forsberg on 2011-08-16.
//  Copyright 2011 Jesper Forsberg. All rights reserved.
//

#import "JSONKit.h"
#import "CategoryRequest.h"

@interface CategoryRequest ()
- (Category *)categoryFromJSON:json;
@end

@implementation CategoryRequest

@synthesize categoryId;

- (id)init
{
    self = [super init];
    if (self) {
        self.categoryId = -1;
    }
    
    return self;
}

- (Category *)categoryFromJSON:(id)json
{
    Category *category = [[Category alloc] init];
    
    category.id = [[json valueForKey:@"id"] intValue];
    category.parentId = [[json valueForKey:@"parentid"] intValue];
    category.name = [json valueForKey:@"name"];
    int childcount = [[json valueForKey:@"childcount"] intValue];
    category.isLeaf = childcount == 0 ? YES : NO;
    
    return [category autorelease];
}

- (CategoryResponse *)query:(QuenchClient *)client
{
    NSString *url = @"/category";
    if (categoryId != -1) {
        url = [NSString stringWithFormat:@"%@/%d", url, categoryId];
    }
    
    NSDictionary *params = [NSDictionary dictionary];
    
    id jsonResponse = [[client queryResource:url withParams:params] objectFromJSONData];
    
    //NSLog(@"%@", NSStringFromClass([jsonResponse class]));
    
    if (![jsonResponse isKindOfClass:[NSDictionary class]]) {
        return nil;
    }

    
    CategoryResponse *response = [[CategoryResponse alloc] init];
    
    Category *requestedCategory = nil;
    if ([[jsonResponse allKeys] containsObject:@"category"]) {
        requestedCategory = [self categoryFromJSON:[jsonResponse valueForKey:@"category"]];
    
        [response setParent:requestedCategory];
    }
    
    NSMutableArray *childCategories = [NSMutableArray array];
    if ([[jsonResponse allKeys] containsObject:@"categories"]) {

        id categoriesObj = [jsonResponse objectForKey:@"categories"];
        for (id obj in categoriesObj) {
            //NSLog(@"%@", obj);
            if (![obj isKindOfClass:[NSDictionary class]]) {
                //NSLog(@"%@", [categoriesObj valueForKey:obj]);
                Category *child = [self categoryFromJSON:[categoriesObj valueForKey:obj]];
                [childCategories addObject:child];
            } else {
                //NSLog(@"%@", obj);
                Category *child = [self categoryFromJSON:obj];
                [childCategories addObject:child];
            }
        }
    }
    
    [response setChildren:childCategories];
    
    return [response autorelease];
}

@end
