//
//  MultiProductRequest.m
//  Compare Prices
//
//  Created by Jesper Forsberg on 2011-08-16.
//  Copyright 2011 Jesper Forsberg. All rights reserved.
//

#import "JSONKit.h"
#import "MultiProductRequest.h"
#import "Product.h"
#import "ProductStore.h"

@implementation MultiProductRequest

@synthesize productIds;

- (id)init
{
    self = [super init];
    if (self) {
        // Initialization code here.
        productIds = [NSArray array];
    }
    
    return self;
}

- (void)dealloc {
    [super dealloc];
}

- (void)addProductIdsObject:(NSInteger)v
{
    productIds = [self.productIds arrayByAddingObject:[NSNumber numberWithInt:v]];
}

- (MultiProductResponse *)query:(QuenchClient *)client
{
    if ([self.productIds count] == 0) {
        @throw [NSException exceptionWithName:@"IllegalStateException" reason:@"you must specify at least one product id" userInfo:nil];
    }
    
    [self addProductIdsObject:0];
    NSMutableString *ids = [NSMutableString string];
    NSString *delim = @"";
    
    for (NSNumber *productId in self.productIds) {
        [ids appendString:delim];
        [ids appendString:[productId stringValue]];
        delim = @",";
    }
    
    NSString *url = [NSString stringWithFormat:@"/product/%@", [NSString stringWithString:ids]];
    NSDictionary *params = [NSDictionary dictionaryWithObject:@"1" forKey:@"showstores"];
    
    id jsonResponse = [[client queryResource:url withParams:params] objectFromJSONData];
    
    MultiProductResponse *response = [[MultiProductResponse alloc] init];
    NSMutableArray *products = [NSMutableArray array];
    
    id productDictObj = [jsonResponse valueForKey:@"product"];
    for (id productObjKey in productDictObj) {
        id productObj = [productDictObj valueForKey:productObjKey];
        
        Product *product = [[Product alloc] init];
        product.id = [[productObj valueForKey:@"id"] intValue];
        product.categoryId = [[productObj valueForKey:@"categoryid"] intValue];
        product.name = [productObj valueForKey:@"name"];
        product.info = [productObj valueForKey:@"description"];
        product.minPrice = [[productObj valueForKey:@"minprice"] floatValue];
        product.maxPrice = [[productObj valueForKey:@"maxprice"] floatValue];
        product.minPrice_c = [productObj valueForKey:@"minprice_c"];
        product.maxPrice_c = [productObj valueForKey:@"maxprice_c"];
        product.storeCount = [[productObj valueForKey:@"storecount"] intValue];
        product.imageURL = [productObj valueForKey:@"imageurl"];
        
        NSMutableArray *stores = [NSMutableArray array];
        for (id storeObj in [productObj valueForKey:@"stores"]) {
            ProductStore *store = [[ProductStore alloc] init];
            store.storeId = [[storeObj valueForKey:@"id"] intValue];
            store.storeName = [storeObj valueForKey:@"name"];
            store.price = [[storeObj valueForKey:@"price"] floatValue];
            store.price_c = [storeObj valueForKey:@"price_c"];
            [stores addObject:store];
            [store release];
        }
        
        [product setStores:stores];
        
        [products addObject:product];
        [product release];
    }
    
    [response setProducts:products];
    return [response autorelease];
}

@end
