//
//  ProductRequest.m
//  Compare Prices
//
//  Created by Jesper Forsberg on 2011-08-14.
//  Copyright 2011 Jesper Forsberg. All rights reserved.
//

#import "ProductRequest.h"
#import "JSONKit.h"

#import "../Models/Product.h"
#import "../Models/ProductImage.h"
#import "../Models/ProductStore.h"

@implementation ProductRequest

@synthesize productId;

- (id)init
{
    self = [super init];
    if (self) {
        // Initialization code here.
    }
    
    return self;
}

- (ProductResponse *)query:(QuenchClient *)client
{
    if (!productId) {
        return nil;
    }
    
    NSString *url = [NSString stringWithFormat:@"/product/%d", productId];
    NSDictionary *params = [NSDictionary dictionary];
    
    id jsonResponse = [[client queryResource:url withParams:params] objectFromJSONData];
    
    if (![jsonResponse isKindOfClass:[NSDictionary class]])
    {
        return nil;
    }
    
    ProductResponse *response = [[ProductResponse alloc] init];
    
    NSDictionary *productDict = [jsonResponse valueForKey:@"product"];
    
    Product *p = [[Product alloc] init];
    p.id = [[productDict valueForKey:@"id"] intValue];
    p.categoryId = [[productDict valueForKey:@"categoryid"] intValue];
    p.name = [productDict valueForKey:@"name"];
    p.info = [productDict valueForKey:@"description"];
    p.minPrice = [[productDict valueForKey:@"minprice"] floatValue];
    p.maxPrice = [[productDict valueForKey:@"maxprice"] floatValue];
    p.minPrice_c = [productDict valueForKey:@"minprice_c"];
    p.maxPrice_c = [productDict valueForKey:@"maxprice_c"];
    p.storeCount = [[productDict valueForKey:@"storecount"] intValue];
    p.imageURL = [productDict valueForKey:@"imageurl"];
    
    id imageArray = [jsonResponse valueForKey:@"images"];
    if (imageArray) {
        NSMutableArray *images = [NSMutableArray array];
        
        for (id imageDict in imageArray) {
            
            if ([imageDict isKindOfClass:[NSDictionary class]]) {
                ProductImage *image = [[ProductImage alloc] init];
                image.id = [[imageDict valueForKey:@"id"] intValue];
                image.microURL = [imageDict valueForKey:@"microurl"];
                image.thumbURL = [imageDict valueForKey:@"thumburl"];
                image.mediumURL = [imageDict valueForKey:@"mediumurl"];
                image.fullURL = [imageDict valueForKey:@"fullurl"];
                image.width = [[imageDict valueForKey:@"width"] intValue];
                image.height = [[imageDict valueForKey:@"height"] intValue];
                
                [images addObject:image];
                [image release];
            }
        }
        
        p.images = [NSArray arrayWithArray:images];
    }
    
    id storeDict = [jsonResponse valueForKey:@"stores"];	
    NSMutableArray *stores = [NSMutableArray array];
    
    for (id storeKey in storeDict) {
        
        id storeItem = [storeDict objectForKey:storeKey];
        if ([storeItem isKindOfClass:[NSDictionary class]]) {
            
            ProductStore *store = [[ProductStore alloc] init];
            store.id = [[storeItem valueForKey:@"id"] intValue];
            store.storeId = [[storeItem valueForKey:@"storeid"] intValue];
            store.storeName = [storeItem valueForKey:@"storename"];
            store.storeInfo = [storeItem valueForKey:@"description"];
            store.price = [[storeItem valueForKey:@"price"] floatValue];
            store.price_c = [storeItem valueForKey:@"price_c"];
            
            [stores addObject:store];
            [store release];
        }
    }
    
    p.stores = [NSArray arrayWithArray:stores];
    
    response.product = p;
    [p release];
    return [response autorelease];
}

@end
